@@ -67,7 +67,7 @@ from . import common as ppc
 copyright = """Copyright (c) 2005-2012 Vitalii Vanovschi.
 Copyright (c) 2015-2016 California Institute of Technology.
 Copyright (c) 2016-2019 The Uncertainty Quantification Foundation."""
-__version__ = version = "1.6.4.9"
+__version__ = version = "1.6.6.1"
 
 # Reconnect persistent rworkers in seconds.
 RECONNECT_WAIT_TIME = 5
@@ -365,8 +365,9 @@ class Server(object):
         pythondirs = [os.getcwd()] + sys.path
 
         if "PYTHONPATH" in os.environ and os.environ["PYTHONPATH"]:
-            pythondirs += os.environ["PYTHONPATH"].split(os.pathsep)
-        os.environ["PYTHONPATH"] = os.pathsep.join(set(pythondirs))
+            pythondirs = os.environ["PYTHONPATH"].split(os.pathsep) + pythondirs
+        dirset = set()        
+        os.environ["PYTHONPATH"] = os.pathsep.join([dirset.add(x) or x for x in pythondirs if x not in dirset])
 
         atexit.register(self.destroy)
         self.__stats = {"local": _Statistics(0)}
@@ -871,7 +872,7 @@ class Server(object):
             try:
                 worker.t.close()
                 if sys.platform.startswith("win"):
-                    os.popen('TASKKILL /PID '+str(worker.pid)+' /F')
+                    os.popen('TASKKILL /PID '+str(worker.pid)+' /F 2>NUL')
                 else:
                     os.kill(worker.pid, 9)
                     os.waitpid(worker.pid, 0)
